@@ -13,11 +13,11 @@ from pyrainsty import connect
 
 def main():
     config = dict(
-        host='39.100.82.18',
-        port=33306,
+        host='121.40.24.251',
+        port=9023,
         user='root',
-        password='qwerty123!@#...',
-        database='rainsty',
+        password='123456',
+        database='storm_monitor',
         charset='utf8'
     )
 
@@ -25,17 +25,21 @@ def main():
     mc.create_connect()
     mc.close_connect()
     mc.check_connect()
-    state, result = mc.get_data('select * from info_re_basinfo limit 1')
+    state, result = mc.get_data('select * from check_time limit %(limit)s', dict(limit=10))
     if not state:
         print(result)
 
     print(result)
     cursor = mc.get_cursor
-    cursor.execute('select * from info_re_basinfo limit 1')
+    cursor.execute('select * from check_time limit 1')
     data = cursor.fetchall()
     for d in data:
         print(d)
 
+    state, result = mc.exec_cmd('select * from check_time limit 1')
+    if not state:
+        print(result)
+
 
 if __name__ == '__main__':
     main()
